
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '37.0.0rc1',
    'branch_nick': 'master',
    'revision_id': '07eb663ed1b7e8681bfdbd7db4cc91ab9ef2c27a',
    'revno': 13606
}
